require_relative '../../../spec_helper'
require 'matrix'

describe "Matrix::Scalar#/" do
  it "needs to be reviewed for spec completeness"
end
